@@ -1,13 +1,15 @@
 package App::optex::textconv::msdoc;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use v5.14;
 use warnings;
 use Carp;
 use utf8;
+use Encode;
 use Data::Dumper;
 
+use App::optex v0.3;
 use App::optex::textconv::Converter 'import';
 
 our @CONVERTER = (
@@ -68,18 +70,19 @@ sub _xml2text {
     $text;
 }
 
-use Archive::Zip qw( :ERROR_CODES :CONSTANTS );
+use Archive::Zip 1.37 qw( :ERROR_CODES :CONSTANTS );
 
 sub to_text {
-    my $zipfile = shift;
-    my $type = ($zipfile =~ /\.(docx|xlsx|pptx)$/)[0] or return;
-    my $zip = Archive::Zip->new($zipfile) or die;
+    my $file = shift;
+    my $type = ($file =~ /\.(docx|xlsx|pptx)$/)[0] or return;
+    my $zip = Archive::Zip->new($file) or die;
     my @contents;
     for my $entry (get_list($zip, $type)) {
 	my $member = $zip->memberNamed($entry) or next;
 	my $xml = $member->contents or next;
-	my $text = xml2text $xml, $type or next;;
-	push @contents, "[ $entry ]\n\n$text";
+	my $text = xml2text $xml, $type or next;
+	$file = encode 'utf8', $file if utf8::is_utf8($file);
+	push @contents, "[ \"$file\" $entry ]\n\n$text";
     }
     join "\n", @contents;
 }
